@@ -173,12 +173,18 @@ class C0000(Cluster):
                       0x0007: {'name': 'power_source', 'value': 'value'},
                       0x0010: {'name': 'description',
                                'value': 'clean_str(value)'},
-                      0xff01: {'name': 'battery_voltage',
-                               'value': "struct.unpack('H', unhexlify(value)[2:4])[0]/1000.",
-                               'unit': 'V', 'type': float},
+                      #   0xff01: {'name': 'battery_voltage',
+                      #            'value': "struct.unpack('H', unhexlify(value)[2:4])[0]/1000.",
+                      #            'unit': 'V', 'type': float},
+                      0xff01: {'name': 'xiaomi',
+                               'value': "decode_xiaomi(value)",
+                               'type': dict},
                       0xff02: {'name': 'battery_voltage',
                                'value': "struct.unpack('H', unhexlify(value)[3:5])[0]/1000.",
                                'unit': 'V', 'type': float},
+                      #   0xff02: {'name': 'xiaomi',
+                      #            'value': "decode_xiaomi(value)",
+                      #            'type': dict},
                       }
 
     def update(self, data):
@@ -190,6 +196,7 @@ class C0000(Cluster):
 
 
 def decode_xiaomi(rawdata):
+    rawdata = unhexlify(rawdata)
     data = {}
     i = 0
     while i < len(rawdata):
@@ -260,6 +267,7 @@ class C0008(Cluster):
     cluster_id = 0x0008
     type = 'General: Level control'
     attributes_def = {0x0000: {'name': 'current_level', 'value': 'int(value*100/254)', 'type': int},
+                      0x0011: {'name': 'current_level2', 'value': 'int(value*100/254)', 'type': int},
                       0xfff0: {'name': 'remote_level_button', 'value': 'value',
                                'type': str, 'expire': 2}
                       }
@@ -420,8 +428,12 @@ class C0201(Cluster):
                                'unit': '°C', 'type': float},
                       0x0002: {'name': 'occupancy', 'value': 'value'},
                       0x0008: {'name': 'heating_demand', 'value': 'value'},
+                      0x0011: {'name': 'occupied_cooling_setpoint', 'value': 'value/100.',
+                               'unit': '°C', 'type': float},
                       0x0012: {'name': 'occupied_heating_setpoint', 'value': 'value/100.',
                                'unit': '°C', 'type': float},
+                      0x0013: {'name': 'unoccupied_cooling_setpoint', 'value': 'value/100.',
+                               'unit': '°C', 'type': float},
                       0x0014: {'name': 'unoccupied_heating_setpoint', 'value': 'value/100.',
                                'unit': '°C', 'type': float},
                       0x001C: {'name': 'system_mode', 'value': 'value'},
@@ -478,6 +490,12 @@ class C0402(Cluster):
                                'unit': '°C', 'type': float},
                       }
 
+    def update(self, data):
+        # ignore erratic value sent by low battery device
+        if data.get('data', 0) < -90 * 100 or data.get('data', 0) > 90 * 100:
+            return
+        return Cluster.update(self, data)
+
 
 @register_cluster
 class C0403(Cluster):
@@ -498,6 +516,12 @@ class C0405(Cluster):
                                'unit': '%', 'type': float},
                       }
 
+    def update(self, data):
+        # ignore erratic value sent by low battery device
+        if data.get('data', 0) < 0 or data.get('data', 0) > 100 * 100:
+            return
+        return Cluster.update(self, data)
+
 
 @register_cluster
 class C0406(Cluster):
@@ -512,7 +536,7 @@ class C0406(Cluster):
 class C0500(Cluster):
     cluster_id = 0x0500
     type = 'Security & Safety: IAS Zone'
-    attributes_def = {255: {'name': 'zone_status', 'value': 'self._decode(value[::-1])',
+    attributes_def = {255: {'name': 'zone_status', 'value': 'self._decode(value)',
                             'type': dict, 'expire': 10, 'expire_value': {'alarm1': False,
                                                                          'alarm2': False,
                                                                          'tamper': False,
@@ -540,6 +564,7 @@ class C0500(Cluster):
     def _decode(self, zone_status):
         if isinstance(zone_status, dict):
             return zone_status
+        zone_status = zone_status[::-1]
         fields = ['alarm1',
                   'alarm2',
                   'tamper',
@@ -601,6 +626,8 @@ class C0702(Cluster):
     type = 'Metering'
     attributes_def = {0x0000: {'name': 'current_delivered', 'value': 'value',
                                'type': float},
+                      0x0400: {'name': 'instant_power', 'value': 'value',
+                               'type': float},
                       }
 
 
